/*
 * Copyright (c) 2011-2013 BlackBerry Limited.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2

TabbedPane {
    
    id: tabPane
    objectName: "obTabbedPane"
    activeTab: worldTab    
    showTabsOnActionBar: false   
    
    onPeekStarted: {
        settingsSheet.close();
        aboutSheet.close();
        helpSheet.close();
    }
    onPeekEnded: {
        settingsSheet.close();
        aboutSheet.close();
        helpSheet.close();
    } 
    
    Menu.definition: MenuDefinition {
        actions: [
            ActionItem {
                title: qsTr("Settings") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "/img/common/ico/ico_opt.png"                    
                shortcuts: [ Shortcut { key: "E" }, Shortcut { key: "e" }]
                onTriggered: {
                    var sheet = settingsSheet.createObject();
                    sheet.open();
                }
            },
            ActionItem {
                title:  qsTr("About") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "/img/common/ico/ico_info.png"
                shortcuts: [ Shortcut { key: "A" }, Shortcut { key: "a" }]
                onTriggered: {
                    var sheet = aboutSheet.createObject();
                    sheet.open();
                }
            },
            ActionItem {
                title:  qsTr("Help") + Retranslate.onLocaleOrLanguageChanged
                imageSource: "/img/common/ico/ico_help.png"
                shortcuts: [ Shortcut { key: "H" }, Shortcut { key: "h" }]
                onTriggered: {
                    var sheet = helpSheet.createObject();
                    sheet.open();
                }
            }            
        ]
    }
    
    attachedObjects: [
        ComponentDefinition {
            id: settingsSheet
            source: "pages/SettingsPage.qml"
            objectName: "objSettingsSheet"
        }
        ,
        ComponentDefinition {
            id: aboutSheet
            source: "pages/AboutPage.qml"
            objectName: "objAboutSheet"
        }
        ,
        ComponentDefinition {
            id: helpSheet
            source: "pages/HelpPage.qml"
            objectName: "objHelpSheet"
        }
    ]
    
    Tab {
        id: worldTab
        title: qsTr("World View") + Retranslate.onLocaleOrLanguageChanged
        objectName: ("objWorldTab")
        shortcuts: [ Shortcut { key: "W" }, Shortcut { key: "w" }]
        delegate: Delegate {
            id: worldPage
            source: "tabs/worldTab.qml"
        }
        imageSource: "/img/tabs/worldTab.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    }
    Tab {
        id: questTab
        title: qsTr("Quest Log") + Retranslate.onLocaleOrLanguageChanged
        objectName: ("objQuestTab")
        shortcuts: [ Shortcut { key: "Q" }, Shortcut { key: "q" }]
        delegate: Delegate {
            id: questPage
            source: "tabs/questTab.qml"
        }
        imageSource: "/img/tabs/questTab.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    }
    Tab {
        id: inventoryTab
        title: qsTr("Inventory") + Retranslate.onLocaleOrLanguageChanged
        objectName: ("objInventoryTab")
        shortcuts: [ Shortcut { key: "I" }, Shortcut { key: "i" }]
        delegate: Delegate {
            id: inventoryPage
            source: "tabs/inventoryTab.qml"
        }
        imageSource: "/img/tabs/inventoryTab.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
    }
    Tab {
        id: statisticsTab
        title: qsTr("Statistics") + Retranslate.onLocaleOrLanguageChanged
        objectName: ("objStatisticsTab")
        shortcuts: [ Shortcut { key: "S" }, Shortcut { key: "s" }]
        delegate: Delegate { 
            id: statisticsPage
            source: "tabs/statisticsTab.qml"
        }
        imageSource: "/img/tabs/statisticsTab.png"
        delegateActivationPolicy: TabDelegateActivationPolicy.Default
   }
   Tab {
       id: magicTab       
       title: qsTr("Magic & Skills") + Retranslate.onLocaleOrLanguageChanged
       objectName: ("objMagicTab")
       shortcuts: [ Shortcut { key: "M" }, Shortcut { key: "M" }]
       delegate: Delegate {
           id: magicPage
           source: "tabs/magicTab.qml"
       }
       imageSource: "/img/tabs/magicTab.png"
       delegateActivationPolicy: TabDelegateActivationPolicy.Default
   }
}