import bb.cascades 1.2
import bb.system 1.0

Page {
    
    property alias notificationText: notificationArea.text
    onCreationCompleted: {
        _downloadManager.getOnlineData("http://www.filearchivehaven.com/data/RPGQuest2/news")        
    }
    titleBar: TitleBar {
        title : qsTr("RPG Quest 2: World View") + Retranslate.onLocaleOrLanguageChanged
    }
    
    Container {
        ImageView {
            imageSource: "asset:///img/common/logos/logo.png"
            loadEffect: ImageViewLoadEffect.Subtle
            scalingMethod: ScalingMethod.AspectFit
            horizontalAlignment: HorizontalAlignment.Fill
        }
        Header {
            title: qsTr("RQ2 News") + Retranslate.onLocaleOrLanguageChanged
        }
        ScrollView {
            Container {
                verticalAlignment: VerticalAlignment.Fill                
                horizontalAlignment: HorizontalAlignment.Fill
                TextArea {
                    maxHeight: 150
                    text: "Accessing server..."
                    id: notificationArea
                    objectName: "objNotificationArea"
                    editable: false
                }
            }
            accessibility.description: "Scrolling"
            accessibility.name: "logScrollView"
        }
        Header {
            title: qsTr("World Options") + Retranslate.onLocaleOrLanguageChanged
        }
    }
    
    attachedObjects: [
        SystemToast {
            id: toast
        }
    ]
    
    actions: [
        // context items
        InvokeActionItem  {
            ActionBar.placement: ActionBarPlacement.InOverflow
            title: qsTr("Share") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///img/common/ico/ico_share.png"
            shortcuts: [ Shortcut { key: "E" }, Shortcut { key: "e" }]
            query {
                mimeType: "text/plain"
                invokeActionId: "bb.action.SHARE"
            }
            onTriggered: {
                data = "..."
            }
        },
        ActionItem {
            title: qsTr("Report Bug") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "/img/common/ico/ico_bug.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            
            attachedObjects: [
                SystemDialog {
                    id: bugDialog
                    title: qsTr("Report Bug") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("Tip:  When submitting a bug report, try to include steps to reproduce the problem.") + Retranslate.onLocaleOrLanguageChanged
                    
                    onFinished: {
                        if (bugDialog.result == SystemUiResult.ConfirmButtonSelection) {
                            bugQuery.trigger("bb.action.SENDEMAIL");
                        }
                    }
                },
                Invocation {
                    id: bugQuery
                    query {
                        mimeType: "text/plain"
                        invokeTargetId: "sys.pim.uib.email.hybridcomposer"
                        uri: "mailto:support@filearchivehaven.com?subject=Bug%20Report%20RPGQuest2%20" + Application.applicationVersion
                    }                   
                }
            ]
            
            onTriggered: {
                bugDialog.show();
            }
        },
        ActionItem {
            title: qsTr("Known Bugs") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "/img/common/ico/ico_knownbug.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "K" }, Shortcut { key: "k" }]
            
            onTriggered: {
                _downloadManager.getOnlineData("http://www.filearchivehaven.com/data/RPGQuest2/bugs")
            }
        },        
        ActionItem {
            title: qsTr("Write Review") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "/img/common/ico/ico_review.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [ Shortcut { key: "R" }, Shortcut { key: "r" }]        
            
            attachedObjects: [
                SystemDialog {
                    id: reviewDialog
                    title: qsTr("Write Review") + Retranslate.onLocaleOrLanguageChanged
                    body: qsTr("I need your help to keep making this application great!  If you experience any issues, please try contacting me before leaving a negative review (so I can fix the problem).  Please be honest in your review, but keep in mind that positive reviews means more users (and ultimately more improvements).") + Retranslate.onLocaleOrLanguageChanged 
                    onFinished: {
                        if (reviewDialog.result == SystemUiResult.ConfirmButtonSelection) {
                            reviewQuery.trigger("bb.action.OPEN")
                        }
                    }
                },
                Invocation {
                    id: reviewQuery
                    query {
                        mimeType: "text/html"
                        invokeTargetId:  "sys.appworld"
                        uri: "appworld://content/59948562"
                    }                   
                }
            ]
            
            onTriggered: {
                reviewDialog.show()
            }
        }
    ]

}
